"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AlgoBlock = void 0;
const globalSettings_1 = require("../../global-settings/globalSettings");
const algoUtils_1 = require("../../utils/algoUtils");
const utils_1 = require("../../utils/utils");
const BlockBase_1 = require("../BlockBase");
const AlgoTransaction_1 = require("../transactions/AlgoTransaction");
class AlgoBlock extends BlockBase_1.BlockBase {
    constructor(data) {
        super(data);
        this.transactionObjects = [];
        this.processTransactions();
    }
    get data() {
        return this.privateData;
    }
    get number() {
        return this.data.block.rnd;
    }
    get blockHash() {
        return (0, algoUtils_1.hexToBase64)(this.data.cert.prop.dig);
    }
    // Algo special
    get blockHashBase32() {
        return (0, algoUtils_1.hexToBase32)(this.data.cert.prop.dig);
    }
    // Algo special
    get blockHashBase64() {
        return (0, algoUtils_1.hexToBase64)(this.data.cert.prop.dig);
    }
    get stdBlockHash() {
        return (0, algoUtils_1.bytesToHex)(this.data.cert.prop.dig);
    }
    get previousBlockHash() {
        return (0, algoUtils_1.hexToBase64)(this.data.block.prev);
    }
    get stdPreviousBlockHash() {
        return (0, algoUtils_1.bytesToHex)(this.data.block.prev);
    }
    get unixTimestamp() {
        return this.data.block.ts;
    }
    get transactionIds() {
        return this.transactionObjects.map((trasn) => {
            return trasn.txid;
        });
    }
    get stdTransactionIds() {
        return this.transactionObjects.map((trasn) => {
            return trasn.stdTxid;
        });
    }
    get transactions() {
        return this.transactionObjects;
    }
    get transactionCount() {
        if (this.data.block.txns) {
            return this.data.block.txns.length;
        }
        return 0;
    }
    ////////////////////////////////////////
    //// Additional transaction objects ////
    ////////////////////////////////////////
    processTransactions() {
        this.transactionObjects = [];
        if (!this.data.block.txns) {
            return;
        }
        for (const transactionBase of this.data.block.txns) {
            try {
                const data = Object.assign({ txid: (0, algoUtils_1.calculateAlgoTxid)(this.data.block.gh, this.data.block.gen, transactionBase), timestamp: this.unixTimestamp, hgi: transactionBase.hgi }, transactionBase.txn);
                if (transactionBase.sig)
                    data.sig = transactionBase.sig;
                if (transactionBase.lsig)
                    data.lsig = transactionBase.lsig;
                if (transactionBase.msig)
                    data.msig = transactionBase.msig;
                if (transactionBase.sgnr)
                    data.sgnr = transactionBase.sgnr;
                this.transactionObjects.push(new AlgoTransaction_1.AlgoTransaction(data));
            }
            catch (e) {
                /* istanbul ignore next */
                // TODO logger
                // TODO What happens if there is a transaction we dont know how to process
                globalSettings_1.mccSettings.loggingCallback(`Unable to process transaction ${(0, utils_1.mccJsonStringify)(transactionBase)}`);
                // throw e;
            }
        }
    }
}
exports.AlgoBlock = AlgoBlock;
//# sourceMappingURL=AlgoBlock.js.map